// Cheap Vernam encoder for SDL surface

#include "cheap-vernam.h"

#include <SDL/SDL.h>

bool SDL_cheap_vernam(uint64_t seed, const SDL_Surface *surface) {
	SDL_PixelFormat *format = surface->format;
	if (format->BytesPerPixel != 3)
		return true;

	int rgb_order[3];
	if (BYTE_ORDER == BIG_ENDIAN) {
		rgb_order[0] = 2 - format->Rshift / 8;
		rgb_order[1] = 2 - format->Gshift / 8;
		rgb_order[2] = 2 - format->Bshift / 8;
	}
	else {
		rgb_order[0] = format->Rshift / 8;
		rgb_order[1] = format->Gshift / 8;
		rgb_order[2] = format->Bshift / 8;
	}

	uint64_t next = seed;
	char *pixels = surface->pixels;
	for (int y = 0; y < surface->h; y++) {
		for (int x = 0; x < surface->w; x++) {
			for (int i = 0; i < 3; i++) {
				int o = y * surface->pitch + x * 3
					+ rgb_order[i];
				next = next * 1103515245 + 12345;
				pixels[o] ^= next / 65536;
			}
		}
	}
	return false;
}
